% -*-trale-prolog-*-
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%   $RCSfile: lexrules.pl,v $
%%  $Revision: 1.10 $
%%      $Date: 2007/03/05 11:26:29 $
%%     Author: Stefan Mueller (Stefan.Mueller@cl.uni-bremen.de)
%%    Purpose: Eine kleine Spielzeuggrammatik für die Lehre
%%   Language: Trale
%      System: TRALE 2.7.5 (release ) under Sicstus 3.12.0
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

:- multifile if/2.
:- discontiguous if/2.
:- multifile fun/1.
:- discontiguous fun/1.
:- multifile ':='/2.
:- discontiguous ':='/2.
:- multifile lex_rule/2.
:- discontiguous lex_rule/2.
:- multifile '*>'/2.
:- discontiguous '*>'/2.

:- lex_rule_depth(5).



verb_movement_lr *>
( %complex_word
  %optionally_coherent_word
  synsem:(loc:cat:(head:(verb,
                         subj:raise(Subj)),
                   subcat:hd:arg:loc:cat:head:dsl:Loc),
          nonloc:Nonloc,
          trace:Trace,
          lex:Lex),
  zu:Zu,
  dtrs:[( word,
          synsem:(loc:(Loc,
                       cat:head:(verb,
                                 subj:Subj,
                                 initial:minus)),
                  nonloc:Nonloc,
                  trace:Trace,
                  lex:Lex),
          zu:Zu)]).


verb_initial_lr *>
( %verb_movement_lr
  %complementizer_like_word
  synsem:loc:cat:head:(vform:fin,
                       subj:[]),
  dtrs:[ synsem:loc:cat:(head:vform:fin,
                         subcat:list_of_non_raised_arguments) ]).


% Sätze mit Verb in Erststellung können Imperativsätze oder auch Interrogativsätze sein.
% Die beiden folgenden Sätze unterscheiden sich nur hinsichtlich ihrer Flexion:
%
%     Gib   Du mir das Buch!
%     Gibst Du mir das Buch?
%
% Die genaue Auflösung der Relation erfolgt erst in der Grammatik für Kapitel 16,
% da dort erst eine Morphologiekomponente eingeführt wird.

% Konditionalsätze werden ignoriert.


(verb_initial_lr,
 synsem:loc:cat:subcat:[arg:nonloc:slash:[]])      *> synsem:loc:cont:nucleus:imperative_or_interrogative.

% Hier spielt das Element in SLASH eine entscheidende Rolle.
% Ist es eine Interrogativphrase, muß ein entsprechender Operator angenommen
% werden. Da die vorliegende Grammatik keine Interrogativpronomina enthält,
% wird die Fallunterscheidung nicht gemacht.

% Er gibt ihm das Buch.
% Jetzt gib mir schon das Buch!
(verb_initial_lr,
 synsem:loc:cat:subcat:[arg:nonloc:slash:ne_list]) *> synsem:loc:cont:nucleus:assertion_or_imperative.

% pres_imp = imp in der kombinerten Tense-Modus-Hierarchie
(s_type,
 arg3:pres_imp) *> imperative.

(s_type,
 arg3:ind_conj) *> assertion_or_interrogative.



verb_initial_lr ##
  Dtr
**>
( verb_initial_lr,
  dtrs:[Dtr])
morphs
  X becomes X.


infl_lr *>
  (affix:fk:FK,
   dtrs:[infl:fk:FK]).

% Nomina und Verben haben morphophonologische Merkmale,
% die mit dem Affix übereinstimmen müssen.
n_v_infl_lr *>
  (%infl_lr,
   affix:morphophon:Morphophon,
   dtrs:[infl:morphophon:Morphophon]).

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Flexionsregel für finite Verben


fin_verb_infl_lr *>
( %complex_word,
  synsem:(loc:(cat:(Cat,
                    head:(verb,
                          initial:minus,
                          subj:[],
                          vform:fin)),
               cont:(nucleus:arg3:Nuc,
                     qstore:QStore)),
          nonloc:Nonloc,
          v2:V2,
          trace:Trace,
          lex:Lex),
  zu:minus,
  dtrs:[( stem,
          synsem:(loc:(cat:Cat,
                       cont:(nucleus:Nuc,
                             qstore:QStore)),
                  nonloc:Nonloc,
                  v2:V2,
                  trace:Trace,
                  lex:Lex)
                  )]).

reg_fin_verb_infl_lr *>
( %fin_verb_infl_lr,
  %n_v_infl_lr,
  synsem:loc:(cat:subcat:subj_verb_agreement(Per,Num),
              cont:nucleus:TeMo),
  affix:(Affix,
         verb_i_suffix,
         per:Per,
         num:Num,
         temo:TeMo),
  dtrs:[infl:affix_:Affix]).              % Das wird theoretisch nicht gebraucht.
                                          % Es ist nur hier, da die relationalen Beschränkungen an LRen
                                          % nur auf den Input der Regel zugreifen können.
                                          % Deshalb reicht es nicht, Information im Output zu haben.


irreg_fin_verb_infl_lr *>
 (phon:Phon,
  dtrs:[phon:Phon]).


fin_verb_infl_lr ##
( stem,
  infl:(v_stems:VStems,
        affix_:(Affix,
                fin_verb_i_suffix,            % Das muß hier auch maximal spezifisch sein, da die Typinferenz, die
                                              % aus dem Vorhandensein von NUM und PER auf die Finitheit schließt,
                                              % erst angewendet wird, wenn die linke Regelseite angeguckt wird.
                phon:[(a_ AffixPhon)])),
  Dtr
) 
 **>
( reg_fin_verb_infl_lr,
  dtrs:[Dtr])
if get_irreg_v_stem(Affix,VStems,a_ IStem)
morphs
  X becomes (X,AffixPhon) when IStem = none,
  X becomes (IStem,AffixPhon).



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Flexionsregel für Infinitive
% Das Subjekt wird aus der SUBCAT-Liste genommen
% und unter SUBJ repräsentiert.

bse_or_inf_verb_infl_lr *>
 (%complex_word
  synsem:(loc:(cat:(head:(verb,
                          initial:(Initial,
                                   minus),
                          vform:VForm,
                          subj:Subj,
                          da:DA,
                          mod:Mod,
                          flip:Flip,
                          auxf:Auxf,
                          prd:Prd),
                    spr:Spr,
                    subcat:block_subject(Subcat,Subj)),
               cont:Cont),
          nonloc:Nonloc,
          lex:Lex,
          trace:Trace),
  dtrs:[(stem,
         synsem:(loc:(cat:(head:(verb,
                                 initial:Initial,
                                 vform:VForm,
                                 da:DA,
                                 mod:Mod,
                                 flip:Flip,
                                 auxf:Auxf,
                                 prd:Prd),
                           spr:Spr,
                           subcat:Subcat),
                      cont:Cont),
                 nonloc:Nonloc,
                 lex:Lex,
                 trace:Trace)) ]).

reg_bse_or_inf_verb_infl_lr *>
 (%bse_or_inf_verb_infl_lr,
  %n_v_infl_lr,
  affix:(verb_i_suffix,
         per:first,
         num:pl,
         temo:pres_ind)).

bse_verb_infl_lr *>
 (%bse_or_inf_verb_infl_lr
  synsem:loc:cat:head:vform:bse,
  zu:minus).

% Infinitive sind fast identisch. Das Ergebniszeichen ist aber vom
% Type zu_word. Dieser kann in keiner Grammatikregel vorkommen, außer
% in einer Regel, die `zu' mit dem Wort kombiniert.
inf_verb_infl_lr *>
 (%bse_or_inf_verb_infl_lr
  synsem:loc:cat:head:vform:inf,
  zu:plus).



bse_verb_infl_lr ##
  Dtr
 **>
( reg_bse_verb_infl_lr,
  affix:phon:[(a_ AffixPhon)],
  dtrs:[Dtr]
)
morphs
  X becomes (X,AffixPhon).


inf_verb_infl_lr ##
  Dtr
 **>
( reg_inf_verb_infl_lr,
  affix:phon:[(a_ AffixPhon)],
  dtrs:[Dtr])
morphs
  X becomes (X,AffixPhon).





ppp_verb_infl_lr *>
( %complex_word,
  synsem:(loc:(cat:(head:(verb,
                          vform:ppp,
                          initial:(Initial,
                                   minus),
                          vform:VForm,
                          subj:DA,
                          da:DA,
                          mod:Mod,
                          flip:(Flip,
                                minus), % except modal verbs, not covered yet 
                          auxf:Auxf,
                          prd:Prd),
                    subcat:block_da(DA,Subcat)),
              cont:Cont),
          nonloc:Nonloc,
          lex:Lex,
          trace:Trace),
  zu:minus,
  dtrs:[(stem,
         synsem:(loc:(cat:(head:(verb,
                                 initial:Initial,
                                 vform:VForm,
                                 da:DA,
                                 mod:Mod,
                                 flip:Flip,
                                 auxf:Auxf,
                                 prd:Prd),
                           subcat:Subcat),
                      cont:Cont),
                 nonloc:Nonloc,
                 lex:Lex,
                 trace:Trace))]).

reg_ppp_verb_infl_lr *>
  affix:ppp_verb_i_suffix.
        
ppp_verb_infl_lr ##
  (infl:(v_stems:part:(a_ IStem),
         bet1:Bet),
   Dtr)
  **>
( reg_ppp_verb_infl_lr,
  affix:phon:[(a_ Suff)],
  dtrs:[Dtr])
if
   (get_prefix(Bet,Ge),
    Ge=(a_ GeP))
morphs
  X becomes (GeP,X,Suff) when IStem = none,
  X becomes (GeP,IStem,Suff).

fun list_of_blocked_arguments(-).
list_of_blocked_arguments(L) if
   when( (L=(e_list;ne_list)),
         undelayed_list_of_blocked_arguments(L) ).

undelayed_list_of_blocked_arguments([]) if true.
undelayed_list_of_blocked_arguments([@blocked_np_ref|T]) if
   list_of_blocked_arguments(T).


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Pränominale Partizipien (`geliebte' und `zu lesende')
%
%
%
part_derivation_lr *>
 (stem,
  synsem:(loc:cat:(head:(attr_participle,         % kann nicht prädikativ genutzt werden,
                                                  % dafür sollte es eine prinzipiellere Erklärung geben.
                         subj:raise([Subj]),
                         da:(DA,
                             list_of_blocked_arguments)),
                   subcat:raise(Subcat)),
          nonloc:Nonloc,
          lex:Lex,
          trace:Trace),
  zu:Zu,
  dtrs:[(word,
         synsem:(loc:cat:(head:(verb,
                                da:DA,
                                flip:minus      % schließt Ersatzinfinitive aus * `wollene' statt `gewollte'
                               ),    
                          subcat:append(Subcat,[(Subj,@np_str)])),
                 nonloc:Nonloc,
                 lex:Lex,
                 trace:Trace),
         zu:Zu,
         % Dies ist ein Hack, der unechte Mehrdeutigkeiten für `angelachte' und `anzulachende' ausschließt.
         % Ohne diese Beschränkung kann die Partikel mit dem Verb kombiniert werden, bevor die Derivation
         % angewendet wird. Dies läßt sich nicht ohne weiteres ausschließen, da man die entsprechende
         % Partizipform für `Sie hat ihn angelacht.' braucht. Allerdings braucht man nach der Derivation
         % auch eine syntaktische Komplexbildung mit Verben und Resultativpräsikaten:
         %
         % die sturmreif geschossene Stadt (aber auch: das plattgefahrene Tier)
         % der schlafen wollende Mann
         %
         % Die Beschränkung funktioniert nur, weil die Affixe nicht in den Tochterlisten verwaltet werden.
         dtrs:[_])]).


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% Partizip II
%
% geliebt (V) -> geliebt (A)
%
% Flexionsregel erzeugt dann: geliebt (A) -> geliebte
%
ppp_part_derivation_lr *>
 (synsem:loc:cont:Cont,
  zu:Zu,
  dtrs:[ (synsem:loc:(cat:head:vform:ppp,
                      cont:Cont),
          zu:Zu)]).

ppp_part_derivation_lr ##
  Dtr
 **>
( ppp_part_derivation_lr,
  dtrs:[Dtr]
  )
morphs
  X becomes X.

% * der zu gelingende Aufsatz
% der zu lesende Aufsatz
inf_part_derivation_lr *>
 (synsem:loc:cont:(qstore:QStore,
                   nucleus:(modal_rel,
                            arg3:VCont)),
  dtrs:[synsem:loc:(cat:head:vform:inf,
                    cont:(qstore:QStore,
                          nucleus:VCont))]).


inf_part_derivation_lr ##
  Dtr
 **>
( inf_part_derivation_lr,
  dtrs:[Dtr]
  )
morphs
  X becomes (X,d).


non_move_synsem :=
  (nonloc:(slash:[],
           rel:[])).

fun list_of_non_move_arguments(-).
list_of_non_move_arguments(L) if
   when( (L=(e_list;ne_list)),
         undelayed_list_of_non_move_arguments(L) ).

undelayed_list_of_non_move_arguments([]) if true.
undelayed_list_of_non_move_arguments([arg: @non_move_synsem|T]) if
   list_of_non_move_arguments(T).


attr_adj_infl_lr *>
(synsem:(loc:cat:(head:(Head,
                        mod:loc:cat:spr:[loc:cat:head:(case:morph_case:Case,
                                                       gen:Genus,
                                                       num:Num,
                                                       dtype:DType)]),
                  subcat:(Subcat,
                          list_of_non_raised_arguments,
                          list_of_non_move_arguments)), % aus dem pränominalen Bereich kann nichts extrahiert werden
                                                        % Relativpronomina sind hier ebenfalls nicht möglich.
         nonloc:Nonloc,
         lex:Lex,
         trace:Trace),
 zu:Zu,
 affix:(attr_adj_i_suffix,
        dtype:DType,
        num:Num,
        gen:Genus,
        morph_case:Case),
 dtrs:[(synsem:(loc:cat:(head:Head,
                         subcat:Subcat),
                nonloc:Nonloc,
                lex:Lex,
                trace:Trace),
        zu:Zu)]).


attr_adj_infl_lr *>
 synsem:loc:cat:head:(subj:[ @pro_np(Ind) ],
                      mod:loc:cont:nucleus:ind:Ind).


isect_attr_adj_infl_lr *>
  (synsem:loc:cont:nucleus:restr:hd:Cont,
   dtrs:[synsem:loc:cont:nucleus:(non_psoa_rel,  % ginge auch mit @not(psoa_rel)
                                                 % aber wegen der Partikelverben ist der negierte Typ nötig.
                                  Cont)]).
      

% prädikative Adjektive sind in dieser Grammatik nicht implementiert.
isect_attr_adj_infl_lr ##
 Dtr
**>
(%@isect_attr_adj_or_participle_word,
 isect_attr_adj_infl_lr,
 affix:phon:[(a_ Suffix)],
 dtrs:[Dtr])
morphs
  X becomes (X,Suffix).

scopal_attr_adj_infl_lr *>
  (synsem:loc:cont:nucleus:restr:[Cont],
   dtrs:[synsem:loc:cont:nucleus:(psoa_rel,
                                  Cont)]).

scopal_attr_adj_infl_lr ##
 Dtr
**>
(%@general_attr_adj_or_participle_word,
 scopal_attr_adj_infl_lr,
 affix:phon:[(a_ Suffix)],
 dtrs:[Dtr])
morphs
  X becomes (X,Suffix).



prd_adj_infl_lr *>
(%complex_word,
 synsem:(loc:(cat:(head:(Head,
                         mod:none,
                         prd:plus),
                   subcat:Subcat),
              cont:Cont),
         nonloc:Nonloc,
         lex:Lex,
         trace:Trace),
 zu:Zu,
 dtrs:[(stem,
        synsem:(loc:(cat:(head:(Head,
                                adj),
                          subcat:Subcat),
                     cont:Cont),
                nonloc:Nonloc,
                lex:Lex,
                trace:Trace),
        zu:Zu)]
 ).

prd_adj_infl_lr ##
  Dtr
 **>
( prd_adj_infl_lr,
  dtrs:[Dtr])
morphs
  X becomes X.



transparent_particle_verb_lr *>
(%stem,
 synsem:(loc:(cat:(head:Head,
                   subcat:[(@argument,
                           arg:
                           (loc:(cat:(head:(part,
                                            subj:ParticleSubj,
                                            mod:InputSynsem),
                                      subcat:ParticleSubcat),
                                 cont:ParticleCont),
                            lex:plus))
                          |append(append(ParticleSubcat,ParticleSubj),InputSubcat)]),
              cont:(ParticleCont,
                    nucleus:non_psoa_rel)),        % Diese Beschränkung ist nur aus technischen Gründen hier.
                                       % Sie sorgt dafür, daß die Adjektivflexionsregel für skopale
                                       % Adjektive nicht angewendet wird. Die Information über den
                                       % semantischen Beitrag ist in der Grammatik erst nach der Kombination
                                       % mit der Verbpartikel bekannt, aber das Adjektiv wird vorher gebildet,
                                       % ohne mit irgendwelchen Partikeln kompatibel zu sein, ist also unnütz.
                                       %
                                       % Das Laden hat sich von 3 min 11 sec auf  2 min 38 sec verkürzt.
                                       % Statt 3410 Lexikoneinheiten wurden nur 3298 erzeugt.
        
         nonloc:Nonloc,
         lex:Lex,
         trace:Trace),
 zu:Zu,
 infl:Infl,
 dtrs:[(stem,
        synsem:(InputSynsem,
                loc:cat:(head:(Head,
                               verb),
                         subcat:(InputSubcat,
                                 [arg:lex:minus]) % Das schränkt die Eingabe auf intransitive Verben ein.
                                                   % Diese Beschränkung ist linguistisch nicht nötig, da
                                                   % sie außerdem von den Partikeln (MOD) kommt. Ohne diese
                                                   % Beschränkung wird allerdings unnötig ein riesiges Lexikon erzeugt.
                        ),
                nonloc:Nonloc,
                lex:Lex,
                trace:Trace),
        zu:Zu,
        infl:Infl)]
 ).

transparent_particle_verb_lr ##
  Dtr
 **>
( transparent_particle_verb_lr,
  dtrs:[Dtr])
morphs
  X becomes X.



get_prefix(plus, (a_ [g,e])) if true.
get_prefix(minus,(a_ [])   ) if true.







get_irreg_v_stem((Affix,
                  phon:Phon),VStems,IrregStem) if
  when(Phon=(e_list;ne_list)
       ,undelayed_get_irreg_v_stem(Affix,VStems,IrregStem)).


undelayed_get_irreg_v_stem((temo:pres_ind_conj),                (pres2:(a_ none)),     (a_ none    ))  if !,true.

% ich fange, du fängst, er fängt
% ich habe, du hast, er hat
undelayed_get_irreg_v_stem((fk:(v_strong;mixed;v_weak),
                            temo:pres_ind, per:second_or_third,num:sg),(pres2:(a_ Pres2Stem)),(a_ Pres2Stem)) if !,true.


undelayed_get_irreg_v_stem((fk:(v_strong;mixed;v_weak),
                            temo:pres_imp),                     (imp_st:(a_ Pres2Stem)),(a_ Pres2Stem)) if !,true.

% Ich darf, du darfst, er darf, wir dürfen, ihr dürft, sie dürfen
% the irregular stem in sg:
undelayed_get_irreg_v_stem((fk:modal,
                            temo:pres_ind,
                            num:sg),                            (pres2:(a_ Pres2Stem)),(a_ Pres2Stem)) if !,true.


undelayed_get_irreg_v_stem((temo:pres_conj,per:second_or_third,num:sg),_,     (a_ none    ))  if !,true.

% ich fange, ich habe
undelayed_get_irreg_v_stem((fk:(v_strong;mixed),
                            temo:pres_ind_conj,per:first,num:sg),      _,                     (a_ none    ))  if !,true.


% versuchtest
undelayed_get_irreg_v_stem((temo:past_ind_conj),                (past:(a_ none),
                                                                 conj:(a_ none)),      (a_ none    ))  if !,true.

% ich fing, ..., ich durfte, ...
undelayed_get_irreg_v_stem((temo:past_ind),                     (past:(a_ PastStem)),  (a_ PastStem))  if !,true.

% If a conj stem is definied, take it, otherwise return the past stem.
% kommen, kam, käme
% fangen, fing, finge
undelayed_get_irreg_v_stem((temo:past_conj),                    (conj:(a_ ConjStem)),  (a_ ConjStem))  if !,prolog(ConjStem\=none).
undelayed_get_irreg_v_stem((temo:past_conj),                    (past:(a_ ConjStem)),  (a_ ConjStem))  if !,prolog(ConjStem=none).


undelayed_get_irreg_v_stem(_,          _,                     (a_ none    ))  if true.



