% -*-trale-prolog-*-
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%   $RCSfile: syntax.pl,v $
%%  $Revision: 1.12 $
%%      $Date: 2007/03/05 11:26:29 $
%%     Author: Stefan Mueller (Stefan.Mueller@cl.uni-bremen.de)
%%    Purpose: Eine kleine Spielzeuggrammatik für die Lehre
%%   Language: Trale
%      System: TRALE 2.7.5 (release ) under Sicstus 3.10.1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



:- multifile ':='/2.
:- discontiguous ':='/2.
:- multifile '*>'/2.
:- discontiguous '*>'/2.
:- multifile if/2.
:- discontiguous if/2.
:- multifile fun/1.
:- discontiguous fun/1.



%% Das Kopfmerkmalsprinzip

headed_phrase *>
   (synsem:loc:cat:head:Head,
    head_dtr:synsem:loc:cat:head:Head).


%% Valenzprinzip

head_argument_phrase *>
   (synsem:loc:cat:subcat:append(FirstPart,append([(arg:NonHeadDtr,
                                                    raised:Raised,
                                                    realized:plus)],LastPart)),
    head_dtr:synsem:loc:cat:subcat:append(FirstPart,append([(arg:NonHeadDtr,
                                                             raised:Raised,
                                                             realized:minus)],LastPart)),
    non_head_dtrs:[synsem:NonHeadDtr]).

head_cluster_phrase *>
 (synsem:loc:cat:subcat:[(arg:NonHeadDtr,
                          raised:Raised,
                          realized:plus)|Rest],
  head_dtr:synsem:loc:cat:subcat:[(arg:NonHeadDtr,
                                   raised:Raised,
                                   realized:minus)|Rest],
  non_head_dtrs:[synsem:NonHeadDtr]).

head_non_argument_non_cluster_phrase *>
   (synsem:loc:cat:subcat:Subcat,
    head_dtr:synsem:loc:cat:subcat:Subcat).


%% Semantikprinzip

head_non_adjunct_phrase *>
   (synsem:loc:cont:Cont,
    head_dtr:synsem:loc:cont:Cont).

head_adjunct_phrase *>
   (synsem:loc:cont:Cont,
    non_head_dtrs:[synsem:loc:cont:Cont]).




%% Kopf-Adjunkt-Strukturen


head_adjunct_phrase *>
   (head_dtr:synsem:HeadSynsem,
    non_head_dtrs:[synsem:(loc:cat:(head:mod:HeadSynsem,
                                    subcat:list_of_spirits),
                           lex:minus)]).


%% Spezifikatorprinzip

(headed_phrase,
 non_head_dtrs:[synsem:loc:cat:head:spec:synsem]) *>
   (head_dtr:synsem:Head,
    non_head_dtrs:[synsem:loc:cat:head:spec:Head]).


head_specifier_phrase *> 
   (synsem:loc:cat:spr:[],
    head_dtr:synsem:loc:cat:(spr:[Spr],
                             subcat:list_of_spirits),
    non_head_dtrs:[synsem:Spr]).

head_non_specifier_phrase *> 
   (synsem:loc:cat:spr:Spr,
    head_dtr:synsem:loc:cat:spr:Spr).



% Teil der Verbbewegungsanalyse

% * Er schläft schläft.
%
(headed_phrase,
 head_dtr:((complex_word;
            simple_word),
           % word, % should be sufficient, seems to be a TRALE bug.
           phon:ne_list)) *> (head_dtr:synsem:loc:cat:head:dsl:none).

% Die obige Implikation schließt auch infintie Verben mit gefülltem
% DSL-Wert aus. Leider nehmen aber nicht alle infiniten Verben Argumente
% oder Adjunkte zu sich, weshalb `Wird geregnet' lizenziert wird, und
% zwar mit der absurden Struktur in der `wird' eine Verbspur verlangt,
% aber mit dem nicht-finiten Verb kombiniert wird.
% Man kann nicht für alle nicht-finiten Verben einfach sagen, daß
% DSL none ist, da dann die mehrfache Vorfeldbesetzung nicht mehr funktionieren
% würde.

(headed_phrase,
 non_head_dtrs:hd:(complex_word,
                                % word, % should be sufficient, seems to be a TRALE bug.
                   phon:ne_list)) *> (non_head_dtrs:hd:synsem:loc:cat:head:dsl:none).


head_filler_phrase *>
   (synsem:nonloc:slash:[],
       head_dtr:synsem:(loc:cat:(head:(verb,
                                       initial:plus),
                                 subcat:list_of_spirits),
                        nonloc:slash:[Slash]),
       non_head_dtrs:[synsem:(loc:Slash,
                              nonloc:(rel:[], % "In der hat er geschlafen." hätte sonst zwei Strukturen.
                                      slash:[]))]).

%%
head_non_filler_phrase *>
   (synsem:nonloc:slash:(list_with_zero_or_one_element,
                         append(Slash1,Slash2)),
       head_dtr:synsem:nonloc:slash:Slash1,
       non_head_dtrs:[synsem:nonloc:slash:Slash2]).


% In Argumentpositionen dürfen nur phrasale Einheiten
% stehen. Das wird gebraucht, da ausgeschlossen werden muß,
% daß "lachen wird" mit dem Kopf-Argument-Schema kombiniert
% wird. `wird' verlangt von seinem Argument, daß es LEX+ ist,
% und das Kopf-Argument-Schem spezifiziert LEX aber als -.
% Somit kann nur das Verbalkomplexschema angewendet werden.
head_argument_phrase *> (non_head_dtrs:[synsem:lex:minus]).

%% Der Kopf kann nicht extrahiert werden.
%% Ein Problem stellt hierbei das Verb in PVP-Konstellationen
%% dar (siehe Müller, 1999)
%% "Helfen wird er ihm morgen."
headed_phrase *>
   (head_dtr:synsem:trace:minus_or_vm).


% Adjunkte sind Extraktionsinseln
(headed_phrase,
 non_head_dtrs:[synsem:trace:extraction]) *>
      (head_dtr:synsem:loc:cat:head:mod:none).


% Das entspricht auch der Analyse von Frey 2004 und Fanselow 2003. Die gehen davon
% aus, daß das höchste Element im Mittelfeld ins Vorfeld vorangestellt werden kann.
% Die pragmatischen Eigenschaften der vorangestellten Konstituente entsprechen dabei
% denen, die sie im Mittelfeld in Initialstellung haben würde.

% Die folgenden Beschränkungen stellen sicher, daß immer das letzte verbleibende
% Argument extrahiert wird, d.h. wenn Extraktion stattgefunden hat kann ein Kopf
% nicht mehr projiziert werden.

% Diese Beschränkung kann aus technischen Gründen nicht mit Bezug auf SUBCAT gemacht
% werden, da sonst del/3 deblockiert werden würde, was nicht erwünscht ist, da die
% SUBCAT-Liste bis zur Kombination mit dem Verb in Erststellung unterspezifiziert ist.
%
% Mit der auskommentierten Beschränkung gibt es für den folgenden Satz 55 Kanten.
%
%   Das Buch gibt er ihr oft.
%
% Mit der verwendeten Beschränkung jedoch nur 48. Das liegt daran, daß `er ihr'
% + Trace dazu führt, daß folgende Abfolgen in der SUBCAT-Liste der Verbspur berechnet
% werden: < Trace, er, ihr >, < er, Trace, ihr >, < er, ihr, Trace >
% Nur eine dieser Abfolgen liegt aber in der SUBCAT-Liste des Verbs in Erststellung
% vor.
   
%(head_argument_phrase,
% non_head_dtrs:[trace:extraction]) *> synsem:loc:cat:subcat:[].

% Wenn die Nicht-Kopftochter eine Extraktionsspur ist, ist die gesamte
% Phrase maximal.
(head_argument_phrase,
 non_head_dtrs:[synsem:trace:extraction]) *> synsem:max_:plus.

% Maximale Phrasen können keine Köpfe in Kopf-Argumentstrukturen sein, da sie ja maximal sind.
% Durch die beiden Beschränkungen wird Maximalität erneut und ohne Bezug auf SUBCAT definiert.
% Wie gesagt, nur ein technischer Trick.
head_argument_phrase *> head_dtr:synsem:max_:minus.


headed_phrase *>
  (synsem:nonloc:rel:(list_with_zero_or_one_element,
                      append(Rel1,Rel2)),
      head_dtr:synsem:nonloc:rel:Rel1,
      non_head_dtrs:[synsem:nonloc:rel:Rel2]).

% Relativsätze
rc *>
 (%isect_n_modifier,
  synsem:(loc:(cat:(head:(relativizer,
                          mod:loc:cont:qstore:[Q]),
                    subcat:[]),
               cont:(nucleus:(ind:Ind,
                              restr:hd:RCCont), %[RCCont|_NP_CONT],
                     qstore:[Q|QStore])),
          nonloc:(rel:[],
                  slash:[])),
  non_head_dtrs:[synsem:(loc:Slash,
                         nonloc:(rel:[Ind],
                                 slash:[])),
                 synsem:(loc:(cat:(head:(verb,
                                         dsl:none,
                                         initial:minus,
                                         vform:fin),
                                   subcat:list_of_spirits),
                              cont:(nucleus:RCCont,
                                    qstore:QStore)),
                         nonloc:(rel:[],
                                 slash:[Slash]),
                                % Der finite Satz selbst darf nicht extrahiert werden.
                                % Das könnte man auch durch loc:Loc, Loc =/= Slash erzwingen.
                         trace:minus)]).



% Die Beschränkung auf Initial:minus für die Nicht-Kopftochter ist in dieser
% Grammatik noch nicht relevant, da es keine Kopulakonstruktionen gibt und somit
% auch keine Nominalphrasen, die einen Komplex bilden könnten, allerdings
% hilft diese Beschränkung bereits, wenn eine Verbspur mit einer Extraktionsspur
% kombiniert worden ist, denn danach könnte dieser Komplex mit jedem beliebigen
% Wort kombiniert werden. Da aber Nomina initial:plus sind, scheiden sie aus.
%
% Die Beschränkung der Kopftochter auf `word' ist zu stark, da dadurch
% Koordination wie "lieben will und muß" ausgeschlossen werden.
% Damit man diese erfassen kann, muß man ein weiteres binäres Merkmal
% einführen.
% Da Adjunkte nur an LEX+ Projektionen gehen und der LEX-Wert von
% Kopf-Adjunktstrukturen nicht spezifiziert wird, wären sonst Adjunkte
% im Verbalkomplex zugelassen.

head_cluster_phrase *> (head_dtr:word,
                        non_head_dtrs:[synsem:loc:cat:head:initial:minus]).

head_argument_phrase  *> (synsem:lex:minus).
head_filler_phrase    *> (synsem:lex:minus).
head_specifier_phrase *> (synsem:lex:minus).


fun list_of_syntactic_signs(-).
list_of_syntactic_signs(L) if
   when( (L=(e_list;ne_list)),
         undelayed_list_of_syntactic_signs(L) ).

undelayed_list_of_syntactic_signs([]) if true.
undelayed_list_of_syntactic_signs([syntactic_sign|T]) if
   list_of_syntactic_signs(T).

% Schließt Stämme in der Syntax aus.
% Stämme als Kopftochter sind bereits in der Signatur ausgeschlossen
phrase *>
   (non_head_dtrs:list_of_syntactic_signs).


fun list_of_zu_minus(-).
list_of_zu_minus(L) if
   when( (L=(e_list;ne_list)),
         list_of_zu_minus2(L) ).


list_of_zu_minus2([]) if true.
list_of_zu_minus2([H|T]) if
   when( (H=(word;phrase)),
         undelayed_list_of_zu_minus([H|T]) ).

undelayed_list_of_zu_minus([]) if true.
undelayed_list_of_zu_minus([(word,
                             zu:minus)|T]) if
   list_of_zu_minus(T).
undelayed_list_of_zu_minus([phrase|T]) if
   list_of_zu_minus(T).

% Sorgt dafür, daß Objekte, die noch ein `zu' benötigen,
% nicht in der Syntax als Töchter auftreten können.
% Das kann nicht ausschließlich an Typen festgemacht werden,
% da `zu lesende' eine Form mit Adjektivflexion ist. Flektierte
% Objekte sind aber normalerweise syntaktische Objekte (z.B. `kluge') 
phrase *> (dtrs:list_of_zu_minus).



% Subjekt-Verb-Kongruenz
%

/*

% Diese Formulierung entspricht der Formulierung im Buch, ist allerdings
% uneffektiv, da eine Liste, die keine Nominative enthält, zweimal vollständig
% durchlaufen werden muß.

% Das Laden der Grammatik dauert ewig ....

fun subj_verb_agreement(-,+,+).
subj_verb_agreement(List,Per,Num) if
  append(_Rest,[@np_str(Per,Num)|list_of_non_nominatives],List).

subj_verb_agreement(list_of_non_nominatives,third,sg) if true.



fun list_of_non_nominatives(-).
list_of_non_nominatives(L) if
   when( (L=(e_list;ne_list)),
         undelayed_list_of_non_nominatives(L) ).

undelayed_list_of_non_nominatives([]) if true.
undelayed_list_of_non_nominatives([@np_lex|T])  if
   list_of_non_nominatives(T).
undelayed_list_of_non_nominatives([@no_noun|T]) if
   list_of_non_nominatives(T).

*/

% für
% Die Aufsätze wurden ihm zu lesen erlaubt.
%
% 1 min 30.740 sec CPU time.        1 solutions; 236 passive edges
% statt
% 2 min 52.210 sec CPU time.        1 solutions; 334 passive edges

% Diese Formulierung arbeitet mit delays. Die Disjunktion kommt erst am Ende
% der Liste ins Spiel, weshalb das ganze effizienter ist. Diese Formulierung
% ist jedoch nicht allgemeingültig, da der Fall np_str,np_lex explizit aufgeführt
% wird, das entspricht nicht genau der Formulierung: "Erster Nominativ"
% 05.06.2006

% Geht durch eine Liste und gibt dem letzten Element die
% Person und Numerus-Merkmale, wenn die Liste mit einer NP_str
% endet. Ansonsten muß das Verb dritte Perosn sg sein.

% Dieses Constraint wird gebraucht, da Modalverben
% nicht wissen, ob sie ein Subjekt haben.


% Subjekt-Verb-Kongruenz
%
% []                kommt nicht vor
% [V[ppp]           wird gearbeitet
% [np_lex]          dürsten
% [np_str]          schlafen
% [np_lex, np_str]  helfen
% [cp]              stimmen
% [np_lex, cp]      auffallen


% there is a list of arguments
% the last one may be a subject. If it is a subject, i.e. np_str_nom
% it has to agree with the verb.
% If the last element is not a noun or has lexical case, the verb
% has to be third sg.


fun subj_verb_agreement(-,+,+).
subj_verb_agreement([H|T],Per,Num) if
  when( T=(e_list;ne_list)
      , undelayed_subj_verb_agreement([H|T],Per,Num)
      ).

% Das sind alle Fälle, in denen T=e_list ist.
undelayed_subj_verb_agreement([@np_str(Per,Num)],         Per,  Num) if true.
undelayed_subj_verb_agreement([@np_lex],                  third,sg)  if true.
undelayed_subj_verb_agreement([@no_noun],                 third,sg)  if true.

% Also muß T jetzt ne_list sein, d.h. die Liste hat mindestens zwei Elemente
undelayed_subj_verb_agreement(List,Per,Num)                          if subj_verb_agreement2(List,Per,Num).

% Wir warten, bis klar ist, wie der Listenrest aussieht.
fun subj_verb_agreement2(-,+,+).
subj_verb_agreement2([H,H2|T],Per,Num) if
  when( T=(e_list;ne_list)
      , undelayed_subj_verb_agreement2([H,H2|T],Per,Num)
      ).

% Wenn es genau zwei Elemente gibt, kann der Fall eintreten, daß
% das erste Element lexikalisch und das zweite strukturell ist.
% Wenn das so ist, gibt es Kongruenz, und wir sind fertig.
undelayed_subj_verb_agreement2([@np_str(Per,Num),@np_lex], Per,  Num) if !,true.

% Wenn das nicht der Fall ist, verkürzen wir die Liste um ein Argument
% und testen erneut alles ab.
undelayed_subj_verb_agreement2([_|T1],                     Per,Num)   if subj_verb_agreement(T1,Per,Num).




/*
fun block_subject(+,-,+).
block_subject([H|T],RestSubcat,Subj) if
   when( T=(e_list;ne_list)
       , undelayed_block_subject([H|T],RestSubcat,Subj)).


% this case does not arise, since all verbs have at least
% one element in their SUBCAT list. For raising verbs this is
% the embedded verb.
%undelayed_block_subject([],[],[]) if true.
% the list may contain only the embedded verb/verbal complex:
% daß gelacht werden (dürfen) kann


undelayed_block_subject([(SubjNP,
                          @np_str)],[],[SubjNP]) if true.
undelayed_block_subject([(Other,
                         @np_lex)],[Other],[]) if true.
undelayed_block_subject([(Other,
                          loc:cat:head:(@not(noun)))],[Other],[]) if true.

undelayed_block_subject([X|T1],[X|T2],Subj) if block_subject(T1,T2,Subj).
*/

fun block_subject(+,-,+).
block_subject(Subcat,RestSubcat,Subj) if
   when( Subcat=(e_list;ne_list)
       , undelayed_block_subject(Subcat,RestSubcat,Subj)).


% this case does not arise, since all verbs have at least
% one element in their SUBCAT list. For raising verbs this is
% the embedded verb.
%undelayed_block_subject([],[],[]) if true.
% the list may contain only the embedded verb/verbal complex:
% daß gelacht werden (dürfen) kann


undelayed_block_subject([(SubjNP,
                          @np_str)],[],[SubjNP]) if true.
undelayed_block_subject([(Other,
                         @np_lex)],[Other],[]) if true.
% undelayed_block_subject([(Other,
%                          @no_noun)],[Other],[]) if true.

undelayed_block_subject([X|T1],[X|T2],Subj) if
  when( T1 = (e_list;ne_list)
      , ( (T1=e_list,
           T2=e_list,
           X= @no_noun,
           Subj=e_list)
        ;
          block_subject(T1,T2,Subj))).


fun block_da(+,+,-).
block_da((DA,
          list_of_non_complex_forming_arguments),         % speed
                                                          % for auxiliaries like `haben', we do not know what the DA is, but we know that
                                                          % it is not complex forming
                                                          % without this constraint the da_blocking would
                                                          % block the embedded ppp_verb (cyclic structure), only to find out
                                                          % later that the DA of the embedded ppp_verb differs from the ppp_verb
         Subcat,RedSubcat) if
  append(RedSubcat,DA,Subcat).



% Kasusprinzip

% Das Kasusprinzip könnte an Lexikoneinträgen festgemacht werden.
% Wegen der mehrfachen Vorfeldbesetzung muß dieses Prinzip aber sowohl für
% Lexikoneinträge von Verben als auch für Spuren gelten.
% [[Der Frau] [das Buch] _] gibt er nicht.

(word,
 synsem:loc:cat:head:adj_or_participle_or_verb) *> (synsem:loc:cat:(head:subj:Subj,
                                                                    subcat:Subcat)) goal assign_case_verb(append(Subcat,Subj)).



fun assign_case_verb(-).

% Da Spuren auch Kasus zuweisen, muß man warten, bis die SUBCAT-Liste überhaupt instantiiert
% ist. Ansonsten, wäre klar, daß es immer ein Argument gibt und man könnte gleich mit
% assign_case_verb2 beginnen.
assign_case_verb(List) if
       when( List=(e_list;ne_list)
           , assign_case_verb2(List)
           ).



assign_case_verb2([(H,
                    raised:R)|T]) if
       when( (R=(plus;minus),
              T=(e_list;ne_list))
           , undelayed_assign_case_verb([H|T])
           ).

% Wenn die Argumente nicht lokal realisiert wurden, passiert nichts.
undelayed_assign_case_verb([raised:plus])      if true.
undelayed_assign_case_verb([raised:plus|Rest]) if assign_case_verb(Rest).

% Wenn die Argumente lokal realisiert wurden, weise NPen mit strukturellem
% Kasus ja nach Position Nominativ oder Akkusativ zu.

% Die letzte NP mit strukturellem Kasus bekommt Nominativ.
undelayed_assign_case_verb([(raised:minus,
                             @np_str,
                             arg:loc:cat:head:case:morph_case:nom)])  if true.

% Ein Aufsatz wurde ihm zu lesen erlaubt.
undelayed_assign_case_verb([(raised:minus,
                             @np_str,
                             arg:loc:cat:head:case:morph_case:nom),@np_lex])  if true.



undelayed_assign_case_verb([(raised:minus,
                             @np_lex)])                                 if true.
undelayed_assign_case_verb([(raised:minus,
                             @no_noun)])                                if true.

% Alle anderen NPen mit strukturellem Kasus bekommen Akkusativ.
% Es muß noch mindestens ein Element in der Valenzliste geben, daß
% nicht durch Passivierung blockiert ist (realized:bool = nicht realized:blocked).
% Für dieses werden die obigen Klauseln angewendet.
undelayed_assign_case_verb([(raised:minus,
                             @np_str,
                             arg:loc:cat:head:case:morph_case:acc),(Nom,
                                                                    @np_str)|Rest])  if assign_case_verb([Nom|Rest]).
% Er verspricht ihm das lied zu singen.
undelayed_assign_case_verb([(raised:minus,
                             @np_str,
                             arg:loc:cat:head:case:morph_case:acc),(Lex,
                                                                    @np_lex),
                                                                   (Nom,
                                                                    @np_str)|Rest])  if assign_case_verb([Lex,Nom|Rest]).
undelayed_assign_case_verb([(raised:minus,
                             @np_lex)|Rest])                                 if assign_case_verb(Rest).
undelayed_assign_case_verb([(raised:minus,
                             @no_noun)|Rest])                                if assign_case_verb(Rest).



fun attract(+,-).
attract(List1,List2) if
       when( (List1=(e_list;ne_list);
              List2=(e_list;ne_list))
           , undelayed_attract(List1,List2)
           ).

undelayed_attract([],[]) if true.
undelayed_attract([(arg:Synsem,
                    realized:Realized)|Rest1],[(realized:Realized,
                                                arg:Synsem)|Rest2]) if attract(Rest1,Rest2).


% Kopiert die ARGUMENT-Werte einer Liste1 in eine Liste2 und markiert die Elemente
% von Liste1 als angezogen.
fun raise(+,-).
raise(List1,List2) if
       when( (List1=(e_list;ne_list);
              List2=(e_list;ne_list))
           , undelayed_raise(List1,List2)
           ).

undelayed_raise([],[]) if true.
undelayed_raise([(arg:Synsem,
                  realized:Realized,
                  raised:plus)|Rest1],[(realized:Realized,
                                        arg:Synsem)|Rest2]) if raise(Rest1,Rest2).



fun list_of_raised_arguments(-).
list_of_raised_arguments(L) if
   when( (L=(e_list;ne_list)),
         undelayed_list_of_raised_arguments(L) ).

undelayed_list_of_raised_arguments([]) if true.
undelayed_list_of_raised_arguments([raised:plus|T]) if
   list_of_raised_arguments(T).


% In inkohärenten Konstruktionen werden nur die nicht realisierten
% Argumente angezogen.
fun attract_unrealized(+,-).
attract_unrealized(List1,List2) if
       when( List1=(e_list;ne_list)
           , undelayed_attract_unrealized(List1,List2)
           ).

undelayed_attract_unrealized([],[]) if true.
undelayed_attract_unrealized([(realized:(minus,
                                         Realized),
                               arg:Synsem,
                               raised:plus)|Rest1],[(realized:Realized,
                                                     arg:Synsem)|Rest2]) if attract_unrealized(Rest1,Rest2).

% Bereits realisierte Argumente werden nicht angehoben.
% Das ist für die inkohärente Konstruktion wichtig.
undelayed_attract_unrealized([(realized:plus,
                               raised:minus)|Rest1],Rest2) if attract_unrealized(Rest1,Rest2).



fun list_of_non_raised_arguments(-).
list_of_non_raised_arguments(L) if
   when( (L=(e_list;ne_list)),
         undelayed_list_of_non_raised_arguments(L) ).

undelayed_list_of_non_raised_arguments([]) if true.
undelayed_list_of_non_raised_arguments([raised:minus|T]) if
   list_of_non_raised_arguments(T).

% Das ist die erste Version gewesen, leider ist sie aber mit der scheinbar mehrfachen Vorfeldbesetzung
% nicht kompatibel. Wenn die MVF als Instanz der kohärenten Konstruktion analysiert werden soll, dann
% ist es für die Analyse von Sätzen wie (1) nötig, die Anhebung von Argumenten eines finiten Verbs zuzulassen.
%
% (1) Der Frau das Buch gibt er nicht.
%
%(word,
% synsem:loc:cat:head:vform:fin) *> synsem:loc:cat:subcat:list_of_non_raised_arguments.

% Bei der folgenden Formulierung wird der raised-Wert erst festgelegt, wenn das Verb in einer
% syntaktischen Struktur verwendet wird.

head_dtr:(%(complex_word;
          %  simple_word),
          complex_word,
           % word, % should be sufficient, seems to be a TRALE bug.
          phon:ne_list, % sonst würde die finite Spur im Vorfeld die Anhebung eines Arguments nicht gestatten.
                        % Leider wird die Implikation somit auch nicht auf die Verbspur in der rechten Satzklammer
                        % im Hauptsatz angewendet. Deshalb muß die Beschränkung noch mal extra in der
                        % Lexikonregel für die Bewegung des finiten Verbs formuliert werden.

          synsem:loc:cat:head:vform:fin) *> synsem:loc:cat:subcat:list_of_non_raised_arguments.



fun list_of_spirits(-).
list_of_spirits(List) if
       when( List=(e_list;ne_list)
           , undelayed_list_of_spirits(List)
           ).

undelayed_list_of_spirits([]) if true.
undelayed_list_of_spirits([realized:plus|Rest]) if list_of_spirits(Rest).




root :=
 (synsem:(loc:cat:(head:dsl:none,
                   spr:[],
                   subcat:list_of_spirits),
          nonloc:slash:[])).

initial_fin_verb :=
 (@root,
  synsem:loc:cat:head:(verb,
                       initial:plus,
                       vform:fin)).

interrog :=
 @initial_fin_verb.

decl :=
 (@initial_fin_verb,
  synsem:v2:plus).
